%global dist_version 2.8.2

%global provider github
%global provider_tld com
%global project docker
%global repo distribution
%global import_path %{provider}.%{provider_tld}/%{project}/%{repo}

%define localname registry
%define srcname %{project}-%{localname}
%define cachedir %{_var}/cache/%{srcname}
%global gopath  %{_libdir}/golang
%global debug_package   %{nil}
%define gosrc %{gopath}/src/pkg/%{import_path}

Summary:        Registry server for Docker
Name:           %srcname
Version:        %dist_version
Release:        %mkrel 1
Group:          System/Configuration
License:        ASL 2.0
URL:            https://%import_path
Source:         https://%import_path/archive/v%{version}.tar.gz
Source1:        %{srcname}.service
Source2:        %{srcname}.sysconfig
Source3:        config.yml

BuildRequires:  systemd
BuildRequires:  gcc
BuildRequires:  glibc-static-devel
# ensure build uses golang 1.4 or above
BuildRequires:  golang >= 1.4

Requires(post):     systemd
Requires(preun):    systemd
Requires(postun):   systemd
Requires(post):   rpm-helper >= %{rpmhelper_required_version}
Requires(preun):  rpm-helper >= %{rpmhelper_required_version}

%description
Registry server for Docker (hosting/delivering of repositories and images).

%prep
%setup -q -n distribution-%{version}
mkdir -p vendor/src
mv vendor/g* vendor/r* vendor/src
mkdir -p vendor/src/%import_path
cd vendor/src/%import_path
for i in blobs.go doc.go errors.go manifests.go registry.go tags.go cmd configuration context contrib digestset health manifest metrics notifications project reference registry testutil uuid version; do
        ln -s ../../../../../$i .
done

%build
export REGISTRY_STORAGE_FILESYSTEM_ROOTDIRECTORY=%{cachedir}
export GOPATH=$(pwd)/vendor:%{_bindir}
go env -w GO111MODULE=off
go build -o bin/%srcname -a %{import_path}/cmd/registry

%install
export REGISTRY_STORAGE_FILESYSTEM_ROOTDIRECTORY=%{cachedir}
install -d %{buildroot}%{_bindir}
install -pm 755 bin/%srcname %{buildroot}%{_bindir}

install -d %{buildroot}%{_sysconfdir}/sysconfig
install -d %{buildroot}%{cachedir}

install -pm 644 %{SOURCE2} %{buildroot}%{_sysconfdir}/sysconfig/%{srcname}

install -d %{buildroot}%{_unitdir}
install -m 644 %{SOURCE1} %{buildroot}%{_unitdir}/%{srcname}.service

install -d %{buildroot}%{_sysconfdir}/%{srcname}
install -pm 644 %{SOURCE3} %{buildroot}%{_sysconfdir}/%{srcname}/

%post
%_post_service %{srcname}

%preun
%_preun_service %{srcname}

%files
%doc LICENSE MAINTAINERS *.md
%config(noreplace) %{_sysconfdir}/%{srcname}/config.yml
%config(noreplace) %{_sysconfdir}/sysconfig/%{srcname}
%{_bindir}/%{name}
%dir %{cachedir}
%{_unitdir}/%{srcname}.service


%changelog
* Sat Jun 17 2023 bcornec <bcornec> 2.8.2-1.mga8
+ Revision: 1962218
- Fix CVE-2023-2253 by updating to upstream 2.8.2 after mgarepo
- Fix CVE-2023-2253 by updating to upstream 2.8.2

* Mon Feb 01 2021 daviddavid <daviddavid> 2.7.1-3.mga8
+ Revision: 1674342
- build dependency on python2 is not needed, let's drop it

* Fri Feb 14 2020 umeabot <umeabot> 2.7.1-2.mga8
+ Revision: 1522634
- Mageia 8 Mass Rebuild

* Tue Feb 05 2019 bcornec <bcornec> 2.7.1-1.mga7
+ Revision: 1363260
- Update to upstream docker-registry 2.7.1

* Sat Dec 08 2018 bcornec <bcornec> 2.7.0-1.mga7
+ Revision: 1338873
- Update to upstream docker-registry 2.7.0

* Thu Oct 11 2018 bcornec <bcornec> 2.6.2-5.mga7
+ Revision: 1319560
- Update to upstream docker-registry 2.6.2

* Sun Sep 23 2018 umeabot <umeabot> 2.5.1-3.mga7
+ Revision: 1297482
- Mageia 7 Mass Rebuild

* Sun Sep 03 2017 daviddavid <daviddavid> 2.5.1-2.mga7
+ Revision: 1151022
- reenable debug package

* Thu May 11 2017 bcornec <bcornec> 2.5.1-1.mga6
+ Revision: 1100156
- Update to upstream 2.5.1 docker-registry
- Update to upstream 2.5.1

* Wed May 25 2016 bcornec <bcornec> 2.4.1-1.mga6
+ Revision: 1018228
- Update docker-registry to upstream 2.4.1

* Thu Feb 18 2016 umeabot <umeabot> 0.9.1-4.mga6
+ Revision: 966154
- Mageia 6 Mass Rebuild

* Thu Jun 25 2015 bcornec <bcornec> 0.9.1-3.mga6
+ Revision: 842709
- bump release tag
- Use mageia macros instead of fedora ones and fix #16192

* Mon Feb 23 2015 bcornec <bcornec> 0.9.1-1.mga5
+ Revision: 816694
- Fix dependencies (recommends openstack modules, remove obsolete python-deocker-registry-core)
- Update docker-registry to 0.9.1 and place content under /var/cache and solve gunicorn startup

* Fri Nov 28 2014 bcornec <bcornec> 0.9.0-1.mga5
+ Revision: 799714
- Merge with some additional content from docker-io-registry which should now be removed
- Update docker-registry to upstream 0.9.0 and remove now useless patches
- Update to upstream 0.9.0

* Wed Oct 15 2014 umeabot <umeabot> 0.8.1-4.mga5
+ Revision: 745900
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.8.1-3.mga5
+ Revision: 678795
- Mageia 5 Mass Rebuild

* Wed Sep 10 2014 bcornec <bcornec> 0.8.1-2.mga5
+ Revision: 674588
- docker-registry now install and is launched via systemd correctly

* Wed Sep 03 2014 bcornec <bcornec> 0.8.1-1.mga5
+ Revision: 671199
- Fix Group entry for docker-registry
- Import docker-registry from fedora with mageia adaptations
- Created package structure for docker-registry.

